@@ -1,10 +1,10 @@
 #!/usr/bin/env bash
 
 # shellcheck disable=SC1090
-source "$(dirname "$0")/../test/e2e-common.sh"
+source "$(dirname "$0")/../vendor/knative.dev/test-infra/scripts/e2e-tests.sh"
 source "$(dirname "$0")/e2e-common.sh"
 
-set -x
+set -Eeuox pipefail
 
 export TEST_IMAGE_TEMPLATE="${IMAGE_FORMAT//\$\{component\}/knative-eventing-test-{{.Name}}}"
 
@@ -18,6 +18,8 @@ failed=0
 
 (( !failed )) && install_serverless || failed=1
 
+(( !failed )) && install_knative_eventing || failed=1
+
 (( !failed )) && run_e2e_tests || failed=1
 
 (( failed )) && dump_cluster_state
